#!/usr/bin/php
<?php

require_once __DIR__.'/deubertit-nagios-php-lib/init.php';

require_once __DIR__.'/deubertit-nagios-php-lib/proxmoxapi.class.php';

/*
 * A note on permissions: Create a separate nagios user, probably only using readonly permissions.
 *
 * Minimal permissions for checkBackups:
 *
 * Function permissions:
 *
 * - getClusterBackup(): ["perm","/",["Sys.Audit"]]
 * - getNodeQemu(): Only list VMs where you have VM.Audit permissons on /vms/<vmid>.
 * - getNodeLxc(): Only list CTs where you have VM.Audit permissons on /vms/<vmid>.
 * - getNodeStorage(): Only list entries where you have 'Datastore.Audit' or 'Datastore.AllocateSpace' permissions on '/storage/<storage>'
 * - getNodeStorageContent(): Check: ["perm","/storage/{storage}",["Datastore.Audit","Datastore.AllocateSpace"],"any",1]
 *
 * User permissions result:
 *
 * - /          Sys.Audit
 * - /vms/*     VM.Audit
 * - /storage/* Datastore.Audit
 *
 * Possible preexisting role: PVEAuditor
 *
 * - / PVEAuditor (missing getNodeStorageContent list entries (probably Datastore.AllocateSpace)
 *
 * Working preexisting role:
 *
 * - / PVEAdmin
 * - / Administrator
 *
 */

define('CRITICAL_AGE_IN_HOURS', 36);

$options = getopt("h:u:p:r::m::v::s::");
$usageString = 'usage: check_proxmox_backups.php -h <HOST> -u <USER> -p <PASSWORD> [-r|estrictToNode <NODE>] [-m <MINIMAL_UPTIME_SECONDS>] [-v|erbose] [-s|kipInactive]';
$requiredKeys = array('h', 'u', 'p');

validateParameters($options, $usageString, $requiredKeys);

$minimalUptime = array_key_exists('m', $options) ? (int) $options['m'] : null;
$verbose = array_key_exists('v', $options);
$skipInactive = array_key_exists('s', $options);

$restrictToNode = (array_key_exists('r', $options) && $options['r']) ? $options['r'] : null;

# parameters

$host = $options['h'];
$user = $options['u'];
$password = $options['p'];

# php check_proxmox_backups.php -h 10.0.0.1 -u NAGIOS -p PASSWORD -v

$service = new ProxmoxApiClient($host, $user, $password, $verbose);

if (!is_null($restrictToNode))
{
    $service->restrictToNode($restrictToNode);
}

$service->checkBackups($skipInactive, $minimalUptime);

# above live should already have exited the script, STATE_UNKNOWN result as fallback

exit(STATE_UNKNOWN);







