#!/usr/bin/php
<?php

require_once __DIR__ . '/deubertit-nagios-php-lib/init.php';
require_once __DIR__ . '/robot-client/RobotRestClient.class.php';
require_once __DIR__ . '/robot-client/RobotClientException.class.php';
require_once __DIR__ . '/robot-client/RobotClient.class.php';

# setup and load parameters

$options = getopt('u:p:f:h:v::');
$usageString = 'usage: check_robot_failover_active_ip.php -u <USER> -p <PASSWORD> -f <FAILOVER_IP> [-h <INTERFACE_URL_OVERRIDE>] [-v|erbose]';
$requiredKeys = array('u', 'p', 'f');

validateParameters($options, $usageString, $requiredKeys);

$user = $options['u'];
$password = $options['p'];
$failoverIp = $options['f'];
$url = array_key_exists('h', $options) ? $options['h'] : 'https://robot-ws.your-server.de';
$verbose = array_key_exists('v', $options);

# processing

try
{
    $client = new RobotClient($url, $user, $password, $verbose);
    $result = $client->failoverGet($failoverIp);
    
    if (!isset($result->failover) || !isset($result->failover->active_server_ip))
    {
        throw new Exception('Invalid response content');
    }
    
    echo 'OK - For failover_ip=', $failoverIp, ' found active_server_ip=', $result->failover->active_server_ip, "\n";
}
catch (Exception $e)
{
    echo 'UNKNOWN - Error occurred: ', $e->getMessage(), "\n";
}

# always return ok

exit(STATE_OK);

