#!/usr/bin/php
<?php

require_once __DIR__ . '/deubertit-nagios-php-lib/init.php';
require_once __DIR__ . '/robot-client/RobotRestClient.class.php';
require_once __DIR__ . '/robot-client/RobotClientException.class.php';
require_once __DIR__ . '/robot-client/RobotClient.class.php';

# setup and load parameters

$options = getopt('u:p:s:h:v::');
$usageString = 'usage: check_robot_storagebox_quota.php -u <USER> -p <PASSWORD> -s <STORAGEBOX_ID> [-h <INTERFACE_URL_OVERRIDE>] [-w <WARN_THR>] [-c <CRIT_THR>] [-v|erbose]';
$requiredKeys = array('u', 'p', 's');

validateParameters($options, $usageString, $requiredKeys);

$user = $options['u'];
$password = $options['p'];
$storageboxId = $options['s'];
$url = array_key_exists('h', $options) ? $options['h'] : 'https://robot-ws.your-server.de';
$warnThreshold = array_key_exists('w', $options) ? (int) $options['w'] : 80;
$critThreshold = array_key_exists('c', $options) ? (int) $options['c'] : 90;
$verbose = array_key_exists('v', $options);

# processing

$resultStatus = STATE_UNKNOWN;

try
{
    if ($warnThreshold < 1 || $warnThreshold > 100
        || $critThreshold < 1 || $critThreshold > 100
        || $critThreshold < $warnThreshold)
    {
        throw new Exception('Invalid threshold value(s) set');
    }

    $client = new RobotClient($url, $user, $password, $verbose);
    $result = $client->storageboxGet($storageboxId);

    if (empty($result) || !isset(reset($result)->storagebox))
    {
        throw new Exception('Invalid response content');
    }
    
    $storagebox = reset($result)->storagebox;
    $diskQuota = $storagebox->disk_quota;
    $diskUsage = $storagebox->disk_usage;
    $used = round($diskUsage / $diskQuota) * 100;
    
    if ($used >= $critThreshold)
    {
        echo 'CRIT';
        $resultStatus = STATE_CRITICAL;
    }
    else if ($used >= $warnThreshold)
    {
        echo 'WARN';
        $resultStatus = STATE_WARNING;
    }
    else
    {
        echo 'OK';
        $resultStatus = STATE_OK;
    }

    echo " - Used space of storagebox_id={$storageboxId} is {$used}% ({$diskUsage} of {$diskQuota})\n";
}
catch (Exception $e)
{
    echo 'UNKNOWN - Error occurred: ', $e->getMessage(), "\n";
}

exit($resultStatus);

