#!/usr/bin/php
<?php

/**
 * Prepare, set params and validate.
 */
require_once(__DIR__ . '/deubertit-nagios-php-lib/init.php');
require_once(__DIR__ . '/sipgate/client.php');

$options = getopt('u:p:t:w:c:');
$usageString = 'usage: check_sms_limit.php [-u <user_id>] [-p <password>] [-t <auth_token>] [-w <warning_threshold=50>] [-c <critical_threshold=15>]';

if (isset($options['u']) && isset($options['p']))
{
    $idOrToken = $options['u'];
    $password = $options['p'];
}
else if (isset($options['t']))
{
    $idOrToken = $options['t'];
    $password = null;
}
else
{
    echo $usageString, "\n";
    exit(STATE_UNKNOWN);
}

$warningThreshold = isset($options['w']) && $options['w']
    ? $options['w']
    : 50;

$criticalThreshold = isset($options['c']) && $options['c']
    ? $options['c']
    : 15;

/**
 * Run.
 */
try
{
    $client = new Sipgate($idOrToken, $password);
    $limit = $client->getLimit();

    if ($limit <= $criticalThreshold)
    {
        echo 'CRITICAL: ', (int) $limit, ' sms left', "\n";
        exit(STATE_CRITICAL);
    }
    else if ($limit <= $warningThreshold)
    {
        echo 'WARNING: ', (int) $limit, ' sms left', "\n";
        exit(STATE_WARNING);
    }
    else
    {
        echo 'OK: ', (int) $limit, ' sms left', "\n";
        exit(STATE_OK);
    }
}
catch (Exception $e)
{
    echo 'Error occurred: ', $e->getMessage(), "\n";
    exit(STATE_UNKNOWN);
}
