#!/usr/bin/php
<?php

/**
 * Prepare, set params and validate.
 */
require_once(__DIR__ . '/deubertit-nagios-php-lib/init.php');
require_once(__DIR__ . '/sipgate/client.php');

$options = getopt('u:p:t:s:r:m:', ['testmode']);
$usageString = 'usage: send_sms.php [-u <user_id>] [-p <password>] [-t <auth_token>] -s <sender> -r <receiver> -m <message_content> [--testmode]';

if (isset($options['u']) && isset($options['p']))
{
    $idOrToken = $options['u'];
    $password = $options['p'];
}
else if (isset($options['t']))
{
    $idOrToken = $options['t'];
    $password = null;
}
else
{
    echo $usageString, "\n";
    exit(STATE_UNKNOWN);
}

if (!isset($options['s']) || !$options['s'])
{
    echo 'Incorrect usage: sender is mandatory', "\n";
    exit(STATE_UNKNOWN);
}
else
{
    $sender = $options['s'];
}

if (!isset($options['r']) || !$options['r'])
{
    echo 'Incorrect usage: receiver is mandatory', "\n";
    exit(STATE_UNKNOWN);
}
else
{
    $receiver = $options['r'];
}

if (!isset($options['m']) || !$options['m'])
{
    echo 'Incorrect usage: message content is mandatory', "\n";
    exit(STATE_UNKNOWN);
}
else
{
    $message = $options['m'];
}

if (isset($options['testmode']))
{
    Sipgate::$test_mode = true;
}

/**
 * Run.
 */
try
{
    $client = new Sipgate($idOrToken, $password);
    $client->setSender($sender);
    $response = $client->sendMessage($receiver, $message);

    echo 'OK: Message sent (', $response, ")\n";
    exit(STATE_OK);
}
catch (Exception $e)
{
    echo 'ERROR occurred: ', $e->getMessage(), "\n";
    exit(STATE_UNKNOWN);
}
